==> haskell-sorted-list-0.2.3.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sorted-list
version:              0.2.3.1
visibility:           public
id:                   sorted-list-0.2.3.1-4V4Gciy2KsRAQ0io3xaorl
key:                  sorted-list-0.2.3.1-4V4Gciy2KsRAQ0io3xaorl
license:              MIT
maintainer:           Daniel Casanueva (coding `at` danielcasanueva.eu)
author:               Daniel Casanueva (coding `at` danielcasanueva.eu)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  688f4c91fd64c118253721f86f64991d
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.3.1-4V4Gciy2KsRAQ0io3xaorl
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sorted-list-0.2.3.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sorted-list
version:              0.2.3.1
visibility:           public
id:                   sorted-list-0.2.3.1-KyIWzOPkddAK5bLEO3YzUZ
key:                  sorted-list-0.2.3.1-KyIWzOPkddAK5bLEO3YzUZ
license:              MIT
maintainer:           Daniel Casanueva (coding `at` danielcasanueva.eu)
author:               Daniel Casanueva (coding `at` danielcasanueva.eu)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  de5fd2d46f36b9498faa011fffd81eac
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sorted-list-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.3.1-KyIWzOPkddAK5bLEO3YzUZ
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
